@@ -1,4 +1,4 @@
-from typing import List
+from __future__ import annotations
 
 import grpc
 import momento_wire_types.cacheclient_pb2_grpc as cache_client
@@ -22,11 +22,9 @@ class _ControlGrpcManager:
 
     def __init__(self, credential_provider: CredentialProvider):
         self._secure_channel = grpc.secure_channel(
-            target=credential_provider.get_control_endpoint(), credentials=grpc.ssl_channel_credentials()
-        )
-        intercept_channel = grpc.intercept_channel(
-            self._secure_channel, *_interceptors(credential_provider.get_auth_token())
+            target=credential_provider.control_endpoint, credentials=grpc.ssl_channel_credentials()
         )
+        intercept_channel = grpc.intercept_channel(self._secure_channel, *_interceptors(credential_provider.auth_token))
         self._stub = control_client.ScsControlStub(intercept_channel)
 
     def close(self) -> None:
@@ -43,12 +41,10 @@ class _DataGrpcManager:
 
     def __init__(self, credential_provider: CredentialProvider):
         self._secure_channel = grpc.secure_channel(
-            target=credential_provider.get_cache_endpoint(),
+            target=credential_provider.cache_endpoint,
             credentials=grpc.ssl_channel_credentials(),
         )
-        intercept_channel = grpc.intercept_channel(
-            self._secure_channel, *_interceptors(credential_provider.get_auth_token())
-        )
+        intercept_channel = grpc.intercept_channel(self._secure_channel, *_interceptors(credential_provider.auth_token))
         self._stub = cache_client.ScsStub(intercept_channel)
 
     def close(self) -> None:
@@ -58,6 +54,6 @@ class _DataGrpcManager:
         return self._stub
 
 
-def _interceptors(auth_token: str) -> List[grpc.UnaryUnaryClientInterceptor]:
+def _interceptors(auth_token: str) -> list[grpc.UnaryUnaryClientInterceptor]:
     headers = [Header("authorization", auth_token), Header("agent", f"python:{_ControlGrpcManager.version}")]
     return [AddHeaderClientInterceptor(headers), *get_retry_interceptor_if_enabled()]
